@@ -1,5 +1,5 @@
 package Amazon::DynamoDB::20120810;
-$Amazon::DynamoDB::20120810::VERSION = '0.28';
+$Amazon::DynamoDB::20120810::VERSION = '0.29';
 use strict;
 use warnings;
 
@@ -465,6 +465,9 @@ method query (CodeRef $code,
               SelectType :$Select,
               TableNameType :$TableName!,
               Int :$ResultLimit where  { $_ > 0 },
+              Str :$FilterExpression,
+              ExpressionAttributeValuesType :$ExpressionAttributeValues,
+              ExpressionAttributeNamesType :$ExpressionAttributeNames,
           ) {
 
     my $payload = _make_payload({
@@ -472,6 +475,9 @@ method query (CodeRef $code,
                                 'ConsistentRead' => $ConsistentRead,
                                 'ConditionalOperator' => $ConditionalOperator,
                                 'ExclusiveStartKey' => $ExclusiveStartKey,
+                                'ExpressionAttributeNames' => $ExpressionAttributeNames,
+                                'ExpressionAttributeValues' => $ExpressionAttributeValues,
+                                'FilterExpression' => $FilterExpression,
                                 'IndexName' => $IndexName,
                                 'Limit' => $Limit,
                                 'QueryFilter' => $QueryFilter,
@@ -507,11 +513,17 @@ method scan (CodeRef $code,
              Int :$Segment where { $_ >= 0 },
              SelectType :$Select,
              TableNameType :$TableName!,
-             Int :$TotalSegments where { $_ >= 1 && $_ <= 1000000 }
+             Int :$TotalSegments where { $_ >= 1 && $_ <= 1000000 },
+             Str :$FilterExpression,
+             ExpressionAttributeValuesType :$ExpressionAttributeValues,
+             ExpressionAttributeNamesType :$ExpressionAttributeNames,
          ) {
     my $payload = _make_payload({
                                 'AttributesToGet' => $AttributesToGet,
                                 'ExclusiveStartKey' => $ExclusiveStartKey,
+                                'ExpressionAttributeValues' => $ExpressionAttributeValues,
+                                'ExpressionAttributeNames' => $ExpressionAttributeNames,
+                                'FilterExpression' => $FilterExpression,
                                 'Limit' => $Limit,
                                 'ReturnConsumedCapacity' => $ReturnConsumedCapacity,
                                 'ScanFilter' => $ScanFilter,
@@ -835,6 +847,7 @@ my $parameter_type_definitions = {
         encode => $encode_key,
     },
     ExclusiveStartTableName => {},    
+    ExpressionAttributeNames => {},
     ExpressionAttributeValues => {
         encode => sub {
             my $source = shift;
@@ -871,6 +884,7 @@ my $parameter_type_definitions = {
             return $r;
         },
     },
+    FilterExpression => {},
     IndexName => {},
     Item => {
         encode => $encode_key,
@@ -982,7 +996,7 @@ Amazon::DynamoDB::20120810
 
 =head1 VERSION
 
-version 0.28
+version 0.29
 
 =head1 DESCRIPTION
 
