@@ -1,5 +1,5 @@
 package Amazon::DynamoDB::Types;
-$Amazon::DynamoDB::Types::VERSION = '0.28';
+$Amazon::DynamoDB::Types::VERSION = '0.29';
 use strict;
 use warnings;
 use Type::Library
@@ -33,6 +33,7 @@ use Type::Library
                       ScanFilterType
                       ExpectedValueType
                       ExpressionAttributeValuesType
+                      ExpressionAttributeNamesType
                       AttributesToGetType);
               
 use Type::Utils -all;
@@ -171,9 +172,12 @@ declare ScanFilterType, as Map[AttributeNameType, Dict[AttributeValueList => Opt
                                                        ComparisonOperator => ComparisonOperatorType
                                                      ]];
 
-declare ExpressionAttributeValuesType, as Map[StrMatch[qr/^:[a-zA-Z][a-z0-9A-Z]*$/], AttributeValueType];
+declare ExpressionAttributeValuesType, as Map[StrMatch[qr/^:[a-zA-Z][a-z0-9A-Z_]*$/], AttributeValueType];
 coerce ExpressionAttributeValuesType, from HashRef, via { ExpressionAttributeValuesType->new($_) };
 
+declare ExpressionAttributeNamesType, as Map[StrMatch[qr/^\#[a-zA-Z][a-z0-9A-Z_]*$/], Str];
+coerce ExpressionAttributeNamesType, from HashRef, via { ExpressionAttributeNamesType->new($_) };
+
 
 1;
 
@@ -189,7 +193,7 @@ Amazon::DynamoDB::Types
 
 =head1 VERSION
 
-version 0.28
+version 0.29
 
 =head1 AUTHORS
 
